@@ -3,9 +3,14 @@ use strict;
 use warnings;
 use base qw(App::Hachero::Plugin::Base);
 
+sub init {
+    my ($self, $context) = @_;
+    $self->{fh} = *STDIN;
+}
+
 sub input : Hook {
     my ($self, $context, $args) = @_;
-    my $fh = *STDIN;
+    my $fh = $self->{fh};
     my $line = <$fh>;
     $context->currentline( $line );
 }
@@ -15,6 +20,8 @@ __END__
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 App::Hachero::Plugin::Input::Stdin - reads logs from STDIN
