@@ -3,19 +3,16 @@ use strict;
 use warnings;
 use base qw(App::Hachero::Plugin::Base);
 use Template;
+use IO::All;
 
 sub output : Hook {
     my ($self, $context, $args) = @_;
     my $tt_file = $self->config->{config}->{template};
     my $out_file = $self->config->{config}->{out};
     my $tt = Template->new;
-    open my $fh_in, '<', $tt_file;
-    my $template = do {local $/; <$fh_in>};
-    close $fh_in;
+    my $template < io $tt_file;
     $tt->process(\$template, $context, \my $out);
-    open my $fh_out, '>', $out_file;
-    print $fh_out $out;
-    close $fh_out;
+    $out > io $out_file;
 }
 
 1;
