@@ -4,7 +4,7 @@ use warnings;
 use base qw(App::Hachero::Plugin::Base);
 use Regexp::Log::Common;
 
-sub initialize : Hook {
+sub init {
     my ($self, $context) = @_;
     my $regexp = Regexp::Log::Common->new(
         format => $self->config->{config}->{format} || ':extended',
@@ -25,6 +25,8 @@ __END__
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 App::Hachero::Plugin::Parse::Common - parses common apache logs
